View source: R/shinyCGNM_related.R
| make_ShinyCGNM_parameterInfo | R Documentation |
A helper function to write out the csv file that can be read in as the parameter info file in shinyCGNM
make_ShinyCGNM_parameterInfo(
ParameterName,
Initial_lower_range,
Initial_upper_range,
Lower_bound = 0,
Upper_bound = NA,
VaryByID = 0,
MO_weight = 0,
MO_value = NA,
Unit = NA,
fileName = NA
)
ParameterName |
(required input) string or vector Name of the parameters. Must cover every parameter used in the ODE_text, every free symbol used in the dose data's dose, start.time, and rate columns, and every free symbol used in the initial condition data's value column. |
Initial_lower_range |
(required input) number or numeric vector lower range of the initial guess used in |
Initial_upper_range |
(required input) number or numeric vector upper range of the initial guess used in |
Lower_bound |
(default: 0) number, NA, or numeric vector used in |
Upper_bound |
(default: NA) number, NA, or numeric vector used in |
VaryByID |
(default: 0) 0, 3, or another positive integer, can be a vector 0: the parameter is shared across all IDs. 3: the parameter varies by the first 3 characters of ID (e.g., to represent an occasion/period). Any other nonzero value: the parameter varies by the full ID. |
MO_weight |
(default: 0) number or numeric vector used in |
MO_value |
(default: NA) number, NA, or numeric vector used in |
Unit |
(default: NA) NA, string, or string vector unit of the parameter, only used for documentation purposes in the generated script. |
fileName |
(default: NA) NA or string |
data.frame if fileName is NA Null if fileName is not NA but instead write out the csv file
make_ShinyCGNM_parameterInfo(
ParameterName=c("ka","CL","V1"),
Initial_lower_range=c(0.01,0.01,0.01),
Initial_upper_range=c(100,100,100)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.