View source: R/shinyCGNM_related.R
| make_ShinyCGNM_simulationTimepoints | R Documentation |
A helper function to build the simulation time point table accepted by
generateCGNM_script's simulationTimepoints_table (used when
includeSimulationCode = TRUE). Unlike make_ShinyCGNM_observationData,
there is no Observed_value/ResidualError_model, since nothing is being fit here
- these are just the time points and expressions to simulate and plot.
make_ShinyCGNM_simulationTimepoints(
ID,
time,
Observation_expression,
Memo = NA,
fileName = NA
)
ID |
(required input) string or vector which individual(s)/scenario(s) to simulate. |
time |
(required input) number or numeric vector time points to simulate at. |
Observation_expression |
(required input) string or string vector the name of a compartment (state variable) or derived (LHS) variable from the ODE, exactly as it appears in ODE_text - unlike |
Memo |
(default: NA) NA, string, or string vector |
fileName |
(default: NA) NA or string |
data.frame if fileName is NA Null if fileName is not NA but instead write out the csv file
make_ShinyCGNM_simulationTimepoints(
ID=1,
time=seq(0,24,by=0.5),
Observation_expression="C_central"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.